@@ -1,6 +1,6 @@
 package CGI::apacheSSI;
 use strict;
-use warnings;
+#use warnings;
 
 # CHANGES for 0.95:
 
@@ -23,7 +23,7 @@ use HTTP::Cookies;
 use Date::Format;
 use Cwd;
 
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 
 our $DEBUG = 0;
 
